@@ -1,6 +1,6 @@
 
 /*
- * $Id: client_side.c,v 1.90.2.6 1997/06/13 17:13:23 wessels Exp $
+ * $Id: client_side.c,v 1.90.2.8 1997/07/04 06:05:58 wessels Exp $
  *
  * DEBUG: section 33    Client-side Routines
  * AUTHOR: Duane Wessels
@@ -375,7 +375,7 @@ proxyAuthenticate(const char *headers)
 
 		debug(33, 5, "proxyAuthenticate: adding new passwords to hash table\n");
 		while (user != NULL) {
-		    if (strlen(user) > 1 && strlen(passwd) > 1) {
+		    if (strlen(user) > 1 && passwd && strlen(passwd) > 1) {
 			debug(33, 6, "proxyAuthenticate: adding %s, %s to hash table\n", user, passwd);
 			hash_insert(validated, xstrdup(user), (void *) xstrdup(passwd));
 		    }
@@ -441,6 +441,7 @@ icpProcessExpired(int fd, void *data)
 	icpState->req_hdr_sz,
 	icpState->request->flags,
 	icpState->method);
+    storeSetLogUrl(entry, icpState->request);
     /* NOTE, don't call storeLockObject(), storeCreateEntry() does it */
     storeClientListAdd(entry, fd, 0);
     storeClientListAdd(icpState->old_entry, fd, 0);
